@@ -30,7 +30,7 @@ class BaseFilter:
         """
         return True
 
-    def fmt_error_message(self, code):
+    def fmt_error_message(self, code):  # pylint: disable=unused-argument
         """ 返回格式化的错误消息
         """
         return None
