@@ -14,15 +14,15 @@ class EmptyFilter(BaseFilter):
     """
     error_code = 560
 
+    def fmt_error_message(self, _):
+        """ 格式化错误消息
+        """
+        return "%s字段不能为空!" % self.key
+
     def __call__(self, *args, **kwargs):
         super(EmptyFilter, self).__call__()
 
-        # 参数输入值为空
-        # BUG: 只有用户不输入的情况下才为None，判断为空应该是当前这种情况
-        # 如果是 not self.value 则包括了多种false情况
-        if self.value is None:
-            if self.rule.allow_empty:
-                self.value = self.rule.default
-            else:
-                raise ParamsValueError(self.error_code, filter=self)
+        if self.value is None and self.rule.required:
+            raise ParamsValueError(self.error_code, filter=self)
+
         return self.value
