@@ -15,6 +15,7 @@ from .filters.base import BaseFilter
 from .filters import simple_filters, complex_filters
 from .response import JSONResponse, HTMLResponse, BaseResponse
 from .rules import Rule
+from .utils import get_deep_value
 from . import filters
 
 
@@ -22,10 +23,12 @@ class PreRequest:
     """ An object to dispatch filters to handler request params
     """
 
-    def __init__(self, content_type=None):
+    def __init__(self, fuzzy=False, store_key=None, content_type=None):
         self.filters = simple_filters
         self.complex_filters = complex_filters
+        self.fuzzy = fuzzy
         self.content_type = content_type or "application/json"
+        self.store_key = store_key or "params"
         self.response = None
         self.formatter = None
 
@@ -82,24 +85,33 @@ class PreRequest:
             self.filters.pop(index)
 
     @staticmethod
-    def _location_params(key, location, default=None):
+    def _location_params(key, location, default=None, deep=True):
         """ 读取指定位置的参数
 
         :param key: 数据的key
         :param location: 读取数据的位置
         :param default: 未读取到时的默认值
+        :param deep: 执行深度递归查询
         """
         from flask import request  # pylint: disable=import-outside-toplevel
 
         location = location.lower()
 
         if location in ["args", "values", "form", "headers", "cookies"]:
-            return getattr(request, location).get(key, default)
+            # query deep value with special key like `userInfo.userId`
+            if len(key.split(".")) > 1 and deep:
+                return getattr(request, location).get(key, default)
+            # load simple params
+            return get_deep_value(key, getattr(request, location), default, deep=False)
 
         if location == "json":
             json_value = getattr(request, location)
             if isinstance(json_value, dict):
-                return json_value.get(key, default)
+                # query deep value with special key like `userInfo.userId`
+                if len(key.split(".")) > 1 and deep:
+                    return json_value.get(key, default)
+                # query simple value from json
+                return get_deep_value(key, json_value, default, deep=deep)
 
         return default
 
@@ -108,105 +120,103 @@ class PreRequest:
 
         :param key: params key
         """
-        # query params from special location
-        if rule.location is not None:
-            for location in rule.location:
-                rst = self._location_params(key, location, default)
-                if rst != default:
-                    return rst
-            return default
-
-        # query params from simple method
+        df_location = ["values", "args", "form", "json", "headers", "cookies"]
         from flask import request  # pylint: disable=import-outside-toplevel
-        value = request.values.get(key, default)
-        if value is not None:
-            return value
 
-        # query params from json request
-        json_value = getattr(request, "json")
-        if json_value and isinstance(json_value, dict):
-            return json_value.get(key, default)
+        if len(key.split(".")) > 1 and rule.deep:
+            rst = get_deep_value(key, getattr(request, "json"), default, deep=True)
+            # load value from depth json structure failed
+            if rst != default:
+                return rst
+
+        rule.location = rule.location or df_location
+
+        # query object from special location
+        for location in rule.location:
+            rst = self._location_params(key, location, default, rule.deep)
+            # can't read params from this location
+            if rst != default:
+                return rst
 
         return default
 
-    def _handler_simple_filter(self, rules, rst):
-        """ 处理普通过滤器
+    def _handler_simple_filter(self, k, r):
+        """ 处理具体规则
 
-        :param rules: 参数规则
-        :param rst: 格式化后的结果值
+        :param k: 参数key
+        :param r: 参数规则
         """
-        for k, r in rules.items():
-            # invalid rule
-            if not isinstance(r, Rule):
-                raise TypeError("invalid rule type for key '%s'" % k)
+        if isinstance(r, dict):
+            fmt_result = dict()
+            for key, rule in r.items():
+                fmt_value = self._handler_simple_filter(k + "." + key, rule)
+                fmt_result[rule.key_map if isinstance(rule, Rule) and rule.key_map else key] = fmt_value
 
-            value = self._fmt_params(k, r)
+            return fmt_result
 
-            # skip filter
-            if r.skip:
-                rst[r.key_map or k] = value
+        if not isinstance(r, Rule):
+            raise TypeError("invalid rule type for key '%s'" % k)
+
+        value = self._fmt_params(k, r)
+
+        if r.skip:
+            return value
+
+        # filter request params
+        for f in self.filters:
+            filter_obj = None
+            # system filter object
+            if isinstance(f, str):
+                filter_obj = getattr(filters, f)(k, value, r)
+
+            # custom filter object
+            elif issubclass(f, BaseFilter):
+                filter_obj = f(k, value, r)
+
+            # ignore invalid and not required filter
+            if not filter_obj or not filter_obj.filter_required():
                 continue
 
-            try:
-                # filter request params
-                for f in self.filters:
-                    filter_obj = None
-                    # system filter object
-                    if isinstance(f, str):
-                        filter_obj = getattr(filters, f)(k, value, r)
+            value = filter_obj()
 
-                    # custom filter object
-                    elif issubclass(f, BaseFilter):
-                        filter_obj = f(k, value, r)
+        if r.callback is not None and isfunction(r.callback):
+            value = r.callback(value)
 
-                    # ignore invalid and not required filter
-                    if not filter_obj or not filter_obj.filter_required():
-                        continue
+        return value
 
-                    value = filter_obj()
-
-                if r.callback is not None and isfunction(r.callback):
-                    value = r.callback(value)
-
-                # simple filter handler
-                rst[r.key_map or k] = value
-            except ParamsValueError as e:
-                return self._f_resp(e)
-
-        return None
-
-    def _handler_complex_filter(self, rules, params):
+    def _handler_complex_filter(self, k, r, rst):
         """ 处理复合过滤器
 
-        :param rules: 参数规则
-        :param params: 所有合规参数
+        :param r: 参数规则
+        :param rst: 所有合规参数
         """
-        for k, r in rules.items():
-            # skip filter
-            if r.skip:
+        if isinstance(r, dict):
+            for key, value in r.items():
+                self._handler_complex_filter(k + "." + key, value, rst)
+            return
+
+        if not isinstance(r, Rule):
+            raise TypeError("invalid rule type for key '%s'" % k)
+
+        if r.skip:
+            return
+
+        # simple filter handler
+        for f in self.complex_filters:
+            filter_obj = None
+            # system filter object
+            if isinstance(f, str):
+                filter_obj = getattr(filters, f)(k, None, r)
+
+            # custom filter object
+            elif issubclass(f, BaseFilter):
+                filter_obj = f(k, None, r)
+
+            # ignore invalid and not required filter
+            if not filter_obj or not filter_obj.filter_required():
                 continue
 
-            try:
-                # simple filter handler
-                for f in self.complex_filters:
-                    filter_obj = None
-                    # system filter object
-                    if isinstance(f, str):
-                        filter_obj = getattr(filters, f)(k, None, r)
-
-                    # custom filter object
-                    elif issubclass(f, BaseFilter):
-                        filter_obj = f(k, None, r)
-
-                    # ignore invalid and not required filter
-                    if not filter_obj or not filter_obj.filter_required():
-                        continue
-
-                    filter_obj(params=params)
-            except ParamsValueError as e:
-                return self._f_resp(e)
-
-        return None
+            filter_obj(params=rst)
 
     def catch(self, rule=None, **options):
         """ Catch request params
@@ -215,8 +225,7 @@ class PreRequest:
             @wraps(func)
             def wrapper(*args, **kwargs):
                 from flask import g, request  # pylint: disable=import-outside-toplevel
-
-                g.params = rst = dict()
+                fmt_rst = dict()
 
                 # ignore with empty rule
                 if not rule and not options:
@@ -234,18 +243,25 @@ class PreRequest:
                     raise ValueError("request method '%s' with invalid filter rule" % request.method)
 
                 # use simple filter to handler params
-                resp = self._handler_simple_filter(rules, rst)
-                if resp is not None:
-                    return resp
+                for k, r in rules.items():
+                    try:
+                        value = self._handler_simple_filter(k, r)
+                        # simple filter handler
+                        fmt_rst[r.key_map if isinstance(r, Rule) and r.key_map else k] = value
+                    except ParamsValueError as e:
+                        return self._f_resp(e)
 
                 # use complex filter to handler params
-                resp = self._handler_complex_filter(rules, rst)
-                if resp is not None:
-                    return resp
+                for k, r in rules.items():
+                    try:
+                        self._handler_complex_filter(k, r, fmt_rst)
+                    except ParamsValueError as e:
+                        return self._f_resp(e)
 
                 # assignment params to func args
-                if "params" in getfullargspec(func).args:
-                    kwargs["params"] = rst
+                setattr(g, self.store_key, fmt_rst)
+                if self.store_key in getfullargspec(func).args:
+                    kwargs[self.store_key] = fmt_rst
 
                 return func(*args, **kwargs)
             return wrapper
@@ -257,9 +273,9 @@ class PreRequest:
         :param error: ParamsValueError
         """
         if self.response is not None:
-            return self.response()(self.formatter, error)
+            return self.response()(self.fuzzy, self.formatter, error)
 
         if self.content_type == "text/html":
-            return HTMLResponse()(self.formatter, error)
+            return HTMLResponse()(self.fuzzy, self.formatter, error)
 
-        return JSONResponse()(self.formatter, error)
+        return JSONResponse()(self.fuzzy, self.formatter, error)
